@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.06';
+$VERSION = '0.07';
 
 #----------------------------------------------------------------------------
 
@@ -22,95 +22,100 @@ my %commands = (
 my %default = ();
 
 my %archlinux = (
-    '0.1'   => 'Homer',
-    '0.2'   => 'Vega',
-    '0.3'   => 'Firefly',
-    '0.4'   => 'Dragon',
-    '0.5'   => 'Nova',
-    '0.6'   => 'Widget',
-    '0.7'   => 'Wombat',
-    '0.8'   => 'Voodoo',
-    '2007.05' => 'Duke',
-    '2007.08' => "Don't Panic",
-    '2008.06' => 'Overlord',
-    '2009.02' => '2009.02',
-    '2009.08' => '2009.08',
-    '2010.05' => '2010.05',
+    '0.1'       => 'Homer',
+    '0.2'       => 'Vega',
+    '0.3'       => 'Firefly',
+    '0.4'       => 'Dragon',
+    '0.5'       => 'Nova',
+    '0.6'       => 'Widget',
+    '0.7'       => 'Wombat',
+    '0.8'       => 'Voodoo',
+    '2007.05'   => 'Duke',
+    '2007.08'   => "Don't Panic",
+    '2008.06'   => 'Overlord',
+    '2009.02'   => '2009.02',
+    '2009.08'   => '2009.08',
+    '2010.05'   => '2010.05',
 );
 
 my %debian = (
-    '1.1'   => 'buzz',
-    '1.2'   => 'rex',
-    '1.3'   => 'bo',
-    '2.0'   => 'hamm',
-    '2.1'   => 'slink',
-    '2.2'   => 'potato',
-    '3.0'   => 'woody',
-    '3.1'   => 'sarge',
-    '4.0'   => 'etch',
-    '5.0'   => 'lenny',
-    '6.0'   => 'squeeze',
+    '1.1'       => 'buzz',
+    '1.2'       => 'rex',
+    '1.3'       => 'bo',
+    '2.0'       => 'hamm',
+    '2.1'       => 'slink',
+    '2.2'       => 'potato',
+    '3.0'       => 'woody',
+    '3.1'       => 'sarge',
+    '4.0'       => 'etch',
+    '5.0'       => 'lenny',
+    '6.0'       => 'squeeze',
+    '7.0'       => 'wheezy',
 );
 
 my %fedora = (
-    '1'     => 'Yarrow',
-    '2'     => 'Tettnang',
-    '3'     => 'Heidelberg',
-    '4'     => 'Stentz',
-    '5'     => 'Bordeaux',
-    '6'     => 'Zod',
-    '7'     => 'Moonshine',
-    '8'     => 'Werewolf',
-    '9'     => 'Sulphur',
-    '10'    => 'Cambridge',
-    '11'    => 'Leonidas',
-    '12'    => 'Constantine',
-    '13'    => 'Goddard',
-    '14'    => 'Laughlin',
+    '1'         => 'Yarrow',
+    '2'         => 'Tettnang',
+    '3'         => 'Heidelberg',
+    '4'         => 'Stentz',
+    '5'         => 'Bordeaux',
+    '6'         => 'Zod',
+    '7'         => 'Moonshine',
+    '8'         => 'Werewolf',
+    '9'         => 'Sulphur',
+    '10'        => 'Cambridge',
+    '11'        => 'Leonidas',
+    '12'        => 'Constantine',
+    '13'        => 'Goddard',
+    '14'        => 'Laughlin',
 );
 
 my %mandriva = (
-    '5.1'   => 'Venice',
-    '5.2'   => 'Leeloo',
-    '5.3'   => 'Festen',
-    '6.0'   => 'Venus',
-    '6.1'   => 'Helios',
-    '7.0'   => 'Air',
-    '7.1'   => 'Helium',
-    '7.2'   => 'Odyssey (called Ulysses during beta)',
-    '8.0'   => 'Traktopel',
-    '8.1'   => 'Vitamin',
-    '8.2'   => 'Bluebird',
-    '9.0'   => 'Dolphin',
-    '9.1'   => 'Bamboo',
-    '9.2'   => 'FiveStar',
-    '10.0'  => 'Community and Official',
-    '10.1'  => 'Community',
-    '10.1'  => 'Official',
-    '10.2'  => 'Limited Edition 2005',
-    '2006.0' => 'Mandriva Linux 2006',
-    '2007'   => 'Mandriva Linux 2007',
-    '2007.1' => 'Mandriva Linux 2007 Spring',
-    '2008.0' => 'Mandriva Linux 2008',
-    '2008.1' => 'Mandriva Linux 2008 Spring',
-    '2009.0' => 'Mandriva Linux 2009',
-    '2009.1' => 'Mandriva Linux 2009 Spring',
-    '2010.0' => 'Mandriva Linux 2010 (Adlie)',
+    '5.1'       => 'Venice',
+    '5.2'       => 'Leeloo',
+    '5.3'       => 'Festen',
+    '6.0'       => 'Venus',
+    '6.1'       => 'Helios',
+    '7.0'       => 'Air',
+    '7.1'       => 'Helium',
+    '7.2'       => 'Odyssey (called Ulysses during beta)',
+    '8.0'       => 'Traktopel',
+    '8.1'       => 'Vitamin',
+    '8.2'       => 'Bluebird',
+    '9.0'       => 'Dolphin',
+    '9.1'       => 'Bamboo',
+    '9.2'       => 'FiveStar',
+    '10.0'      => 'Community and Official',
+    '10.1'      => 'Community',
+    '10.1'      => 'Official',
+    '10.2'      => 'Limited Edition 2005',
+    '2006.0'    => 'Mandriva Linux 2006',
+    '2007'      => 'Mandriva Linux 2007',
+    '2007.1'    => 'Mandriva Linux 2007 Spring',
+    '2008.0'    => 'Mandriva Linux 2008',
+    '2008.1'    => 'Mandriva Linux 2008 Spring',
+    '2009.0'    => 'Mandriva Linux 2009',
+    '2009.1'    => 'Mandriva Linux 2009 Spring',
+    '2010.0'    => 'Mandriva Linux 2010 (Adlie)',
+    '2010.1'    => 'Mandriva Linux 2010 Spring',
+    '2010.2'    => 'Mandriva Linux 2010.2',
 );
 
 my %ubuntu = (
-    '4.10'  => 'Warty Warthog',
-    '5.04'  => 'Hoary Hedgehog',
-    '5.10'  => 'Breezy Badger',
-    '6.06'  => 'Dapper Drake',
-    '6.10'  => 'Edgy Eft',
-    '7.04'  => 'Feisty Fawn',
-    '7.10'  => 'Gutsy Gibbon',
-    '8.04'  => 'Hardy Heron',
-    '8.10'  => 'Intrepid Ibex',
-    '9.04'  => 'Jaunty Jackalope',
-    '9.10'  => 'Karmic Koala',
-	'10.04' => 'Lucid Lynx',
+    '4.10'      => 'Warty Warthog',
+    '5.04'      => 'Hoary Hedgehog',
+    '5.10'      => 'Breezy Badger',
+    '6.06'      => 'Dapper Drake',
+    '6.10'      => 'Edgy Eft',
+    '7.04'      => 'Feisty Fawn',
+    '7.10'      => 'Gutsy Gibbon',
+    '8.04'      => 'Hardy Heron',
+    '8.10'      => 'Intrepid Ibex',
+    '9.04'      => 'Jaunty Jackalope',
+    '9.10'      => 'Karmic Koala',
+    '10.04'     => 'Lucid Lynx',
+    '10.10'     => 'Maverick Meerkat',
+    '11.04'     => 'Natty Narwhal',
 );
              
 my %distributions = (
@@ -339,7 +344,7 @@ RT Queue: http://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Platform-Info
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2010 Birmingham Perl Mongers
+  Copyright (C) 2010-2011 Birmingham Perl Mongers
 
   This module is free software; you can redistribute it and/or
   modify it under the Artistic License 2.0.
